@@ -22,7 +22,7 @@ def create_virtual_env(name: str, rootProject: str, rootApi: str):
     chdir(rootProject)  # mueve a carpeta del proyecto
     if platform.system() == 'Windows':
         exe_cmd = "python -m venv {0}-venv & {1}/{0}-venv/Scripts/activate".format(name, rootProject)
-        subprocess.run("{0} & pip install --upgrade pip & pip install -r {1}/requirements.txt".format(exe_cmd, rootApi), shell=True)
+        subprocess.run("{0} & pip install --upgrade pip --user & pip install -r {1}/requirements.txt --user".format(exe_cmd, rootApi), shell=True)
     else:
         exe_cmd = "python3 -m venv {0}-venv; source ./{0}-venv/bin/activate;".format(name)
         system(exe_cmd + "pip install --upgrade pip; pip install -r {1}/requirements.txt".format(exe_cmd, rootApi))
